package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````*```````````0```````
M`,'(``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*P8````````K!@`
M```````0``````$````&````````NZ@```````"[J````````+NH````````
M!.`````````%"````````!```````@````8```````"[N````````+NX````
M````N[@````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````I.@```````"DZ````````*3H`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+NH````````NZ@`````
M``"[J`````````18````````!%@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`>DX(_[^797B200=9:`BJ*DF\3U@````$````$```
M``%'3E4```````````,````"````````````````````0P````````!=````
M``````````````````````````!7````````````````````+P`````````P
M````````````````````4````````````````````"H`````````5```````
M```[`````````"@`````````5@````````!"`````````#$`````````/```
M````````````````````````````.```````````````````````````````
M-P`````````7`````````$X`````````*P`````````R`````````!8`````
M````40````````!/````````````````````````````````````````````
M````````*0`````````=`````````"4```````````````````!-````````
M`$P````````````````````_````````````````````/@````````!:````
M````````````````(P`````````$````````````````````20``````````
M``````````8```````````````````!9`````````#H`````````&0``````
M``!!````````````````````2`````````!5`````````!@`````````-@``
M```````+`````````$,`````````/0`````````M`````````$4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````H``````````@``````````````````
M``4`````````2P```````````````````$8`````````$@````````!;````
M````````````````````````````````````````````````"```````````
M``````````X`````````4@`````````,``````````<`````````&P``````
M```3````````````````````#0```````````````````"0`````````````
M`````````````````%,`````````)@````````````````````D`````````
M```````````@`````````````````````````````````````````!X`````
M```````````````G``````````\`````````-0````````!*````````````
M````````,P`````````B`````````!0`````````$0`````````N````````
M`!P`````````'P````````!$````````````````````````````````````
M`````"P`````````7```````````````````````````````(0``````````
M````````````````````6``````````0````````````````````%0``````
M`````````````#D`````````0````````````````````$<`````````&@``
M```````T````````````````````````````````````````````````````
M``````````````````````,````1````0P````0````(A`1`!0`0$""$`(:`
M!``"*`@$(`D"`(F""`(`ND$0@(@`````````0P```$8```!)````2@```%(`
M``!3````5`````````!6````5P```%@```!9````6@```%P``````````!_?
MQ6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C2ZR'U_I"+#_E
MPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,%0N7.@V;G*E_
M"@*GX%">&FM)^^"C```````````````````````````````````````````#
M```,````````'F```````````````V\2````````````````````````````
M`I\2`````````````````````````````(P1````````````````````````
M`````<,2`````````````````````````````@82````````````````````
M`````````H82`````````````````````````````-(2````````````````
M`````````````D(2``````````````````````````````$@````````````
M`````````````````G\2`````````````````````````````&<2````````
M`````````````````````;82`````````````````````````````-L2````
M`````````````````````````M$2`````````````````````````````842
M`````````````````````````````?82````````````````````````````
M`2D2`````````````````````````````6H2````````````````````````
M`````)02`````````````````````````````!`@````````````````````
M`````````K<2`````````````````````````````2`2````````````````
M`````````````(H1`````````````````````````````3<2````````````
M`````````````````"P@`````````````````````````````)T2````````
M`````````````````````JD2`````````````````````````````5L2````
M`````````````````````````.$6`````````````````````````````/02
M`````````````````````````````7X2````````````````````````````
M`E42`````````````````````````````0\2````````````````````````
M`````L(2`````````````````````````````+,2````````````````````
M`````````%@B`````````````````````````````=`2````````````````
M`````````````;$2`````````````````````````````3X2````````````
M`````````````````<H2`````````````````````````````6,2````````
M`````````````````````:(2`````````````````````````````I$2````
M`````````````````````````B<2`````````````````````````````'D2
M`````````````````````````````7<2````````````````````````````
M`>$2`````````````````````````````)P2````````````````````````
M`````,L2`````````````````````````````A(2````````````````````
M`````````;X2`````````````````````````````G,2````````````````
M`````````````J02`````````````````````````````>\2````````````
M`````````````````F81`````````````````````````````8P2````````
M`````````````````````*02`````````````````````````````+T2````
M`````````````````````````002`````````````````````````````4T2
M`````````````````````````````*L2````````````````````````````
M`C,2`````````````````````````````$82````````````````````````
M`````902`````````````````````````````9L1````````````````````
M`````````W@2```.````````7L``````````S@```\T2```.````````58``
M```````&_@```%,2```.````````)8`````````"@````N\2```.````````
M1]``````````!@```PT2```.````````7(`````````"/@```_,2```.````
M````1]@````````":````[,0```8````````P(@``````````````P`2```.
M````````2D``````````-````R,2```.````````46``````````=@```X01
M```0````````9%@`````````!````Z`2```.````````8``````````!P```
M`ZL2```.````````1I@`````````.````\@0```8````````P+``````````
M`````^$2```.````````5)``````````\```!`H2```.````````4=@`````
M````>````Y,0```7````````P````````````````T<2```.````````2G@`
M```````!5````]H0```8````````P(@`````````````!``1```7````````
MP(``````````"````YD2```.````````*````````````````[\2```.````
M````7Y``````````;````Y4@```7````````P````````````````UT2```.
M````````5&``````````+````S$2```.````````1M``````````_@```U,2
M```.````````8<`````````"5```!!(2```.````````2]`````````%C`!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL
M`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A
M9&1I<C8T`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`%!,
M7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!0
M97)L7VYE=UA37V9L86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR
M`%!E<FQ?<W9?<V5T<'9N`%]?;65M;6]V95]C:&L`<F5A;&QO8P!G971P:60`
M7U]M96UC<'E?8VAK`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<G)C:'(`;65M
M8W!Y`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!G
M971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P
M96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F
M<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P
M97)L7W)U;@!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`
M7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXS,P!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`+W5S<B]L
M:6(O<&5R;#4O-2XS."XR+W,S.3!X+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%
M``````````(``0`"``(``0`!``(``0`!``(``P`"``(``0`"``$``0`$``(`
M`0`!``(``@`"``$`!0`!``(``0`!``(``0`!``$``@`"``(``@`!``(``@`&
M``$``0`&``(`!@`%``(``0`"``$``@`"``$``@`"``8``0`$``(``0`'``(`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`&```"Y0```!``````!I:1M`````<```0?````$`UI:10`
M```&```$*@```!`&EI&S````!0``!#0````0"6D9=`````0```0_````$`EI
M&7(````#```$2P```!`-:6D2`````@``!%<`````````````NZ@`````````
M#````````"D`````````N[``````````#````````"BX````````O_@`````
M````#````````"6`````````P`@`````````#````````,`(````````P"``
M````````#````````*3(````````P"@`````````#````````&2T````````
MP#@`````````#````````&54````````P$``````````#````````&58````
M````P$@`````````#````````*2\````````P%``````````#````````&2Z
M````````P%@`````````#````````*3$````````P&@`````````#```````
M`*2L````````P'``````````#````````*2R````````P(``````````#```
M`````&<\````````OZ`````$````"@``````````````````OZ@````)````
M"@``````````````````O[`````*````"@``````````````````O[@````5
M````"@``````````````````O\`````:````"@``````````````````O\@`
M```>````.```````````````````O]`````?````"@``````````````````
MO]@````A````"@``````````````````O^`````E````"@``````````````
M````O^@````X````"@``````````````````O_````!"````"@``````````
M````````O?`````"````"P``````````````````O?@````#````"P``````
M````````````O@`````%````"P``````````````````O@@````&````"P``
M````````````````OA`````'````"P``````````````````OA@````(````
M"P``````````````````OB`````+````"P``````````````````OB@````,
M````"P``````````````````OC`````-````"P``````````````````OC@`
M```.````"P``````````````````OD`````/````"P``````````````````
MOD@````0````"P``````````````````OE`````1````"P``````````````
M````OE@````2````"P``````````````````OF`````3````"P``````````
M````````OF@````4````"P``````````````````OG`````6````"P``````
M````````````OG@````7````"P``````````````````OH`````9````"P``
M````````````````OH@````;````"P``````````````````OI`````<````
M"P``````````````````OI@````=````"P``````````````````OJ`````@
M````"P``````````````````OJ@````B````"P``````````````````OK``
M```C````"P``````````````````OK@````D````"P``````````````````
MOL`````E````"P``````````````````OL@````F````"P``````````````
M````OM`````G````"P``````````````````OM@````H````"P``````````
M````````ON`````I````"P``````````````````ON@````J````"P``````
M````````````OO`````K````"P``````````````````OO@````L````"P``
M````````````````OP`````M````"P``````````````````OP@````N````
M"P``````````````````OQ`````O````"P``````````````````OQ@````P
M````"P``````````````````OR`````Q````"P``````````````````OR@`
M```R````"P``````````````````OS`````S````"P``````````````````
MOS@````T````"P``````````````````OT`````U````"P``````````````
M````OT@````V````"P``````````````````OU`````W````"P``````````
M````````OU@````Y````"P``````````````````OV`````Z````"P``````
M````````````OV@````[````"P``````````````````OW`````\````"P``
M````````````````OW@````]````"P``````````````````OX`````^````
M"P``````````````````OX@````_````"P``````````````````OY````!`
M````"P``````````````````OY@```!!````"P``````````ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```3[+`$```4)OC$!````2Y`@`1IX0``PWAXT#Q$``$
MZV_PT``$!_0``.,0\#@`),`0``!/F=('\#`0".,0$!``!`?Q!P`'``<`P!``
M`$^8XQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```3XSC$!````0'\0T0
MXQ`0#``4P/3____5````&,`0``!/@.,0$```!`?Q#1#C$!`,`!3`]/___\4`
M```PP!```$]TXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```3VCC$!``
M``0'\0T0XQ`0#``4P/3___^E````8,`0``!/7.,0$```!`?Q#1#C$!`,`!3`
M]/___Y4```!XP!```$]0XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```
M3T3C$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!/..,0$```!`?Q#1#C
M$!`,`!3`]/___V4```#`P!```$\LXQ`0```$!_$-$.,0$`P`%,#T____50``
M`-C`$```3R#C$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!/%.,0$```
M!`?Q#1#C$!`,`!3`]/___S4```$(P!```$\(XQ`0```$!_$-$.,0$`P`%,#T
M____)0```2#`$```3OSC$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!.
M\.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```$[DXQ`0```$!_$-$.,0
M$`P`%,#T___^]0```6C`$```3MCC$!````0'\0T0XQ`0#``4P/3___[E```!
M@,`0``!.S.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```$[`XQ`0```$
M!_$-$.,0$`P`%,#T___^Q0```;#`$```3K3C$!````0'\0T0XQ`0#``4P/3_
M__ZU```!R,`0``!.J.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```$Z<
MXQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```3I#C$!````0'\0T0XQ`0
M#``4P/3___Z%```"$,`0``!.A.,0$```!`?Q#1#C$!`,`!3`]/___G4```(H
MP!```$YXXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```3FSC$!````0'
M\0T0XQ`0#``4P/3___Y5```"6,`0``!.8.,0$```!`?Q#1#C$!`,`!3`]/__
M_D4```)PP!```$Y4XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```3DCC
M$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!./.,0$```!`?Q#1#C$!`,
M`!3`]/___A4```*XP!```$XPXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`
M$```3B3C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!.&.,0$```!`?Q
M#1#C$!`,`!3`]/___>4```,`P!```$X,XQ`0```$!_$-$.,0$`P`%,#T___]
MU0```QC`$```3@#C$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!-].,0
M$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```$WHXQ`0```$!_$-$.,0$`P`
M%,#T___]I0```V#`$```3=SC$!````0'\0T0XQ`0#``4P/3___V5```#>,`0
M``!-T.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```$W$XQ`0```$!_$-
M$.,0$`P`%,#T___]=0```ZC`$```3;CC$!````0'\0T0XQ`0#``4P/3___UE
M```#P,`0``!-K.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```$V@XQ`0
M```$!_$-$.,0$`P`%,#T___]10```_#`$```393C$!````0'\0T0XQ`0#``4
MP/3___TU```$",`0``!-B.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!``
M`$U\XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```37#C$!````0'\0T0
MXQ`0#``4P/3___T%```$4,`0``!-9.,0$```!`?Q#1#C$!`,`!3`]/___/4`
M``1HP!```$U8XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```34SC$!``
M``0'\0T0XQ`0#``4P/3___S5```$F,`0``!-0.,0$```!`?Q#1#C$!`,`!3`
M]/___,4```2PP!```$TTXQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```
M32CC$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!-'.,0$```!`?Q#1#C
M$!`,`!3`]/___)4```3XZV_P,``DX_#_./]QXS#PJ``DXT#PH``D4"#PM$%`
M\*!!,/"H02#PM+)/`+#KNP`@``VR3P"QT@?PP+`HP.7___^RQ$@``$SSQ"@`
M`$T(N00`-,#E```?(\08``!-")4`$`"GA`"VP#```$SQXU`P```$6*#PM.R:
M``0`V+D4`.GC9;````3K+@`#``V6`V2*IZH``\#E___^]N,0\*@`!,`P```@
MBN,`$```!.,P(`@`).,`(```)+D$`%+$*P``32[`0```('OC0%`8`"3$*```
M31GC(%`0`"18D/"T[)P`Q0%^[.D``P#8[`G__P#803`0"*<H``2G`0`!IW0`
M@H@```&Y%`!"[!(``0#8Z^0``P`-N10`8>-`,```!.-.4```).L6``,`#>-@
M,`@`!.-A4```)*<J``*G.P`0IP;_X^QI``,`V+D4`):Y%`!*ZZD``P`-02I0
M`*=I``#E2"````#`,```#<[$*```3-_`Y?___"CL*`!4`'[$*```3-9!8/"\
MP.7___WMN00`-KD$`)+`(```'OG`Y0``#$/L*`!'`'S$*```3,'`Y?__^]K`
MY?___0?5!_#`L"BG=`!9N00`*>MO\/@`!`?^P.7___RYQ"L``$RJ["@`3@!\
MP.7___TPP#```$PQXR`P```$XT*P```$D@!)?J?T_SCC,#````3C,%`@`"2G
M*``%03`0$.PN_W9@=J?T_Y3$*```3(7`Y?___"ZG]/^IP%```$QYXR!0```"
MIX0`!\#E```;@:?T_[&Y!``VP"```!YUP.4```OGQ"L``$QD["C_I`!\I_3_
M[:=H``2G]/]NP.7___V8IRD``<#E___](T%`\`CC,/````2G"?_PN8``\*?[
M_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```2^7C("````3`Y?___H,`
M``<'!P<'!\`0``!,(,`@``!,'>P2``J`9,08``!+K^P8``0`?`?Q!_X'!P<'
M!P?`$```3`S`(```3`FY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`"NPX``T`
M?,08``!+DNP8``<`?,`@``!+\`?Q!_X'!P<'!P?KO_!8`"3`L```2^7C\/]@
M_W&5`+``IW0`%<`0``!+A^,0$````J>$``C$*```2Y/`Y?___(S`Y?___ZV2
M`;``Z[_P^``$!_[`]/___[@'!^MO\#``)./P_-#_<;)/`+#KNP`@``VR3P"Q
M01#PJ-('\RBP**<)``1!4"`XXT!0```$XS!0"``$ZZ0`(``,XZ`0```DZV,`
M(``,XV`0$``DP$H`````XT`0"``DP#H`````XS`0&``D05!0$*<;`""G!__>
MXS#Q$``$XX#Q&``$XQ#Q(``$XY#PJ``$XP#PL``$04#PN*>I`$"Y!`!QX]!`
M```$N00`[>/@0#``@KF"`..Y@@#I[!X@OR%5[!X@/@%6XQ!`<``DN00`.+D$
M`)"Y!`"'ITL`"*>G"MCCX"````3C8"`(``3C8/"@`"3C0"`0``3C`"`8``3L
MKB"_)56YYP"4[*X@.@56N8``EKF"`)#K5@`"``SC</"P``3L5@`A'E;">EJ"
M>9GL-2"_`%6Y"`!PN><PU.,0\*@`!+F``-["&EJ">9FY@@#4XQ`@(``(N>AP
MC;D(`!KKK@`"``RY"``9[*X`(1Y6[)$@OP!5N>>@9;F``&FY@@!C[-$[OR55
MXU#PP``$[-D`.@56PEI:@GF9N0@`V+D(`%/L?2"_`%7LC3N_)57K.0`"``SL
MAP`Z!5;L.0`A'E;C$/"X``3"&EJ">9FY"``4N0@`%NQJ(+\`5;F"`*.Y"``8
MN>1PBNR1(+\`5>S1.[\E5;D$`*WLJ0`Z!5:Y@@"&XQ#PR``$N0@`A<(:6H)Y
MF;D(`(JYZ&!1ZZ<``@`,[&,@OP!5[*<`(1Y6['@@OP!5[(@[OR55[(<`.@56
MN8(`.N/0\-``!+F``#G"VEJ">9FY@@`VN0@`-;GH8%VY"``X[&H@OP!5ZXD`
M`@`,[(D`(1Y6[),@OP!5N8(`J.PS.[\E5;GD<!KCT/#8``2Y@@`6PMI:@GF9
MN0@`%;D$`*.YZ&!=[*D`.@56[&@@OP!5N0@`&NLW``(`#.PW`"$>5KF"`(/L
M<2"_`%7LH3N_)56YY)`8N00`BNR'`#H%5KF"`!;CT/#@``2Y"``5PMI:@GF9
MN0@`&+GH8%WLH3N_)57L8R"_`%7KB0`"``SLB0`A'E;LD2"_`%7LJ0`Z!5:Y
M@@`XXQ#PZ``$N8``-\(:6H)YF;F"`#:Y"``UN>A@4;D(`#KL:""_`%7KIP`"
M``SLIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#P
M\``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3
M(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\/@`!+D(`#7"&EJ">9FY
M"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`X
MN00`C>R'`#H%5KF"`#;C$/$```2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL
M:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`V
MXQ#Q"``$N0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`
MBNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0\1``!+D(`#7"&EJ"
M>9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)56Y
MY'`ZN00`K>RI`#H%5KF"`#;C$/$8``2Y"``UPAI:@GF9N0@`.KGH8%'KIP`"
M``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y
M@@`VXQ#Q(``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6
MN8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\2@`!+D(`#7"
M&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_
M)56YY)`XN00`C>R'`#H%5KF"`#;C$/$P``2Y"``UPAI:@GF9N0@`.+GH8%'K
MB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55XQ#Q.``$N>1P.L(:
M6H)YF;F"`#:Y!`"MN0@`->RI`#H%5KGH8%&Y"``Z[&@@OP!5[-,[OR55ZZ<`
M`@`,[-,@.@56[*<`(1Y6P#H`````N>>@>..`\4``!+F``'G"BEJ">9FY@@!V
MN>A@&+D(`'7K60`"``RY"`!][%D`(1Y6[)<[OR55[)<@.@56[&H@OP!5N>=0
MVNN#``(`#+F``-.Y@@#6N0@`T;D(`-FY!`"8[),`(1Y6[#T[OR55N>>0%>P]
M(#H%5KF"`!?CH/%(``3C@/%0``3"JF[9ZZ'"BF[9ZZ&Y"`"FN1H`A;D:`*'L
M9R*_/E6Y"`"C[&<"(1Y6[#H[OR55N>=@&>PZ(#H%5KF"`!WL?2*_/E6Y&@"!
M['T"(1Y6N0@`@^,P\5@`!,(Z;MGKH;GG<%:Y&@`YN>>@E>P8.[\E5;D:`#GL
M&"`Z!5;CD/%@``2Y"``QPIINV>NA[-,[OR55N1H`ENS3(#H%5NQJ(K\^5>QJ
M`B$>5N.@\6@`!+GG8%?"JF[9ZZ&Y@@!8N1H`I[D:`)7L>"*_/E6Y"`"=['@"
M(1Y6[(D[OR55[(D@.@56N>=PUK/!`&CC@/%P``3"BF[9ZZ&Y&@"&L\T`9KF"
M`-.Y&@"MN0@`INQ:.[\E5>Q:(#H%5NQC(K\^5>,0\7@`!.QC`B$>5L(:;MGK
MH;GG8#>Y&@`7N8(`.>QY(K\^5;D:`(/L>0(A'E:Y"`"%N>=P5NR8.[\E5;F"
M`%KLF"`Z!5:Y&@`5XS#Q@``$N0@`&<(Z;MGKH>R:(K\^5;D:`#;LF@(A'E;L
MT3N_)56YYY!7[-$@.@56N8(`6..@\8@`!+D:`#7"JF[9ZZ&Y"``]N1H`I^QX
M(K\^5>QX`B$>5NR#.[\E5>R#(#H%5KGG<-FSP0!XXX#QD``$PHINV>NAN1H`
MB;/-`)>Y@@#1N1H`K;D(`*GL6CN_)57L6B`Z!5;L82*_/E7L80(A'E;C$/&8
M``2YYV#7PAINV>NAN8(`T[D:`!>Y&@"-[',BOSY5N0@`A>QS`B$>5NPX.[\E
M5;GG<%;L."`Z!5:Y@@!:XY#QH``$N1H`%<*:;MGKH;D(`!.Y&@"6[#HBOSY5
M[-$[OR55[#H"(1Y6[-$@.@56N><P5^.@\:@`!+F"`%C"JF[9ZZ&Y&@"5N1H`
MI[D(`)WL>"*_/E7L>`(A'E;LB3N_)57LB2`Z!5:YYW#3L\$`:..`\;``!,**
M;MGKH;D:`(.SS0`VN8(`T;D:`*VY"`"C[%H[OR55[%H@.@56[&$BOSY5[&$"
M(1Y6XQ#QN``$N>=@U\(:;MGKH;F"`-FY&@`7N1H`C>QY(K\^5;D(`(7L>0(A
M'E;LF#N_)56YYW!6[)@@.@56N8(`6N,P\<``!+D:`!7".F[9ZZ&Y"``9N1H`
M-NR:(K\^5>S1.[\E5>R:`B$>5NS1(#H%5KGGD%?CH/'(``2Y@@!8PJINV>NA
MN1H`-;D:`*>Y"``]['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=PV;/!`'CC
M@/'0``3"BF[9ZZ&Y&@")L\T`E[F"`-'L82*_/E6Y&@"M[&$"(1Y6N>=@U[F"
M`-.Y"`"IN1H`C>Q:.[\E5>S3(K\^5>Q:(#H%5NS3`B$>5KGGT):Y@@":N0@`
MA>,0\=@`!.PX(+\`5>Q8.[\E5<(:;MGKH>Q3`#H%5KD:`!>Y&@`9[)HBOSY5
MN0@`%>R:`B$>5N.@\>``!+GGD'W"JF[9ZZ&Y@@"'N1H`INQA(+\`5>P1.[\E
M5>P6`#H%5KD:`*CC@/'H``2Y"`"APHJ/&[S<ZQ,``@`,N1H`C>P3`"$>5NS1
M(+\`5;GDT%FSP0`H[#H[OR55[(H@OP!5N>80J;F``*:Y@0"EL\T`4N-P\?``
M!,)ZCQN\W.PX`#H%5KD(`*6Y!`!7XW#Q^``$N1H`6<)ZCQN\W.N6``(`#.R6
M`"$>5KGDT&FY@0`9N>C0U[F``!BY@0`6N0@`%;D(`*.SP0!M[#H@OP!5[*H[
MOR55[*,`.@56N0@`H>L8``(`#.P8`"$>5NS1(+\`5;GDT%GL:B"_`%7LBCN_
M)56YYA"IN8``H[F!`*6SS0!6[(8`.@56XW#R```$N0@`I;D(`*C">H\;O-SK
M@P`"``RY!`!7[(,`(1Y6N1H`6>PZ.[\E5>R:(+\`5;F!`!BYY-"HN8``%KF!
M`!JY"``5[#D`.@56XW#R"``$N0@`,<)ZCQN\W.L6``(`#+GHT-?L%@`A'E;L
M82"_`%6YY&!8L\$`/;GF$-BY@`#9N8$`U;/-`%/L<R"_`%7L,SN_)57L-P`Z
M!5:Y"`#5N0@`T^LY``(`#.PY`"$>5KGD8).Y@0`3XZ#R$``$N8``%\*JCQN\
MW+F!`!FY!`!:N1H`6.R-(+\`5;D(`!7LW3N_)57LV``Z!5:Y"`#1[)T@OP!5
MZQ<``@`,[!<`(1Y6XW#R&``$PGJ/&[S<N>A@9^QQ(+\`5;GD<%.YYA"CL\$`
M=KF``*BY@0"EL\T`5^S=.[\E5>-@\B``!+D(`*7LV0`Z!5;":H\;O-RY"`#:
MN00`5NRM(+\`5;D:`%/LW3N_)57K.``"``SLV@`Z!5;L.``A'E:YYC"!N>1P
M$[F``(FY@0"!ZQD``@`,N0@`A>P9`"$>5KD(`(WLT2"_`%6YY-!3N>80D^-@
M\B@`!+F``)K":H\;O-RY@0"5N0@`9[/!`":SS0!2['@@OP!5XV#R,``$N0@`
ME<)JCQN\W.R(.[\E5;D$`%;LAP`Z!5:Y&@!3N>B`.>N:``(`#.R:`"$>5KGD
MT*FY@0`9N8``%[F!`!JY"``5[(,@OP!5[&,[OR55XS#R.``$[&@`.@56PCJ/
M&[S<N0@`8>L7``(`#.P7`"$>5NQQ(+\`5;GD<%FYZ-#3N>80.;/!`&VY@``X
MN8$`-;/-`%;CT/)```3"VH\;O-SLIB"_`%6Y"``U[&8[OR55N00`7>QJ`#H%
M5KD:`%GCT/)(``3KF``"``S"VH\;O-SLF``A'E:YY'")N8$`&;GH<'VY@``:
MN8$`&+D(`!6Y"``VL\$`-^QC(+\`5>PS.[\E5>PV`#H%5KGH,%'K&@`"``SL
M&@`A'E;LT2"_`%6YY-!YN>80J;F``*:Y@0"GL\T`<^PU(+\`5>R%.[\E5;D(
M`*?L@P`Z!5:Y"`"HXU#R4``$['H@OP!5[(H[OR55PEJ/&[S<XZ#R6``$N1H`
M6<*JCQN\W.N6``(`#.R6`"$>5KGDT&FY@0`9N>C0VKF``!.Y@0`6N0@`%>R'
M`#H%5K/!`'VY"`"!ZQ,``@`,[!,`(1Y6[-$@OP!5N>306;GF$*FY@`"GN8$`
MI;/-`%?L:""_`%7L.#N_)56Y"`"E[#8`.@56XX#R8``$PHJ/&[S<N00`6+D:
M`%GKEP`"``SLEP`A'E:YY-!YN8$`&;F``!:Y@0`7N0@`%;D(`*/C@/)H``3L
M.B"_`%7"BH\;O-SLJCN_)57LHP`Z!5:Y"`"AZQ8``@`,[!8`(1Y6[&$@OP!5
MN>1@6>QZ(+\`5;GHT-CLBCN_)56SP0`MN>80J;F``*.Y@0"EL\T`4NR'`#H%
M5N/0\G``!+D(`*7"VH\;O-RY"`"HN00`7;D:`%GLVB"_`%7KDP`"``SLDP`A
M'E;L.CN_)56YY&")N8$`&>P]`#H%5KF``!?CH/)X``2Y@0`8PJJ/&[S<N0@`
M%;GH8%JY"``Q[&,[OR55[&,@.@56ZQ<``@`,L\$`9NP7`"$>5N-@\H``!.R!
M(+\`5;GF$'FYY("IPFJ/&[S<N1H`:;/-`):Y@`!]N8$`>KD(`'6YZ)"7[%D[
MOR55[%D@.@56L\$`%NM]``(`#.Q]`"$>5KD$`-6SS0!1N>2`I^-@\H@`!,)J
MRF+!UKGH@(;`.@````"Y@0`7L\$`.+F``!/K@P`"``RY@0`:[(,`(1Y6N0@`
M%;/-`&.Y"``=XZ#RD``$N>>`U\*JRF+!UKF"`-FY&@"G['DBOSY5['D"(1Y6
MXY#RF``$PIK*8L'6N1H`F+/!`%JSP0`)L\T`E;D:`&WL,3N_)57L,2`Z!5:Y
M"``V[%,[OR55[%,@.@56N>=PJ+F"`*&Y&@":N0@`E;/-`%#L82*_/E7L80(A
M'E:YYV#7N8(`T^P9.[\E5;D:`%WL&2`Z!5:Y"``5[*$[OR55[*$@.@56L\$`
M*K/-`-+C@/*@``3CH/*H``3"BLIBP=;"JLIBP=:Y&@"'N1H`INQS(K\^5>QS
M`B$>5KGG<#;L:2*_/E6Y@@`Y[&D"(1Y6N1H`@[GG8%>Y"`"-N8(`4>R8.[\E
M5;D:`*7LF"`Z!5:Y"`"I[-H[OR55[-H@.@56[)$BOSY5XS#RL``$[)$"(1Y6
MPCK*8L'6N>>05KD:`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;C$/*X``2S
MP0`=PAK*8L'6X]#RP``$N1H`%L+:RF+!UNQH(K\^5;D:`-GL:`(A'E:YYV")
ML\T`D;F"`(KL>B*_/E6Y&@`8['H"(1Y6N0@`&;GG<(;L43N_)56Y@@"#[%$@
M.@56XZ#RR``$PJK*8L'6N1H`IKD$`&WLTR*_/E6Y&@!HN0@`9>S3`B$>5KGG
MT#>Y@@`Q[%8[OR55N1H`H^Q6(#H%5KD(`*7L.CN_)57L.B`Z!5;C@/+0``3"
MBLIBP=:Y&@"'['$BOSY5['$"(1Y6XQ#RV``$N>=P7<(:RF+!UKF"`%:Y&@`=
MN1H`A>S6(K\^5;D(`(/LU@(A'E;L.#N_)56YY]!G[#@@.@56N8(`:KD:`!:Y
M"``3[#HBOSY5[#H"(1Y6N><P;;F"`&CL43N_)57CD/+@``3L42`Z!5;"FLIB
MP=:Y&@"7N1H`ENQH(K\^5;D(`)7L:`(A'E;LB3N_)57LB2`Z!5:YYV!SL\$`
M2..`\O``!,**RF+!UKD:`(.SS0`TN8(`<>.@\N@`!,*JRF+!UKD:`*VY&@"G
M['$BOSY5N0@`H^QQ`B$>5NQ:.[\E5;GG<-;L6B`Z!5:Y@@#9XQ#R^``$N1H`
MC<(:RF+!UKD(`(6Y&@`6[&DBOSY5[&D"(1Y6[)@[OR55N>=@5^R8(#H%5KF"
M`%JY&@`5N0@`&>S1.[\E5>S1(#H%5NR:(K\^5>,P\P``!.R:`B$>5L(ZRF+!
MUKGGD%:Y&@`WN8(`6+D:`#6Y"``][-,[OR55[-,@.@56XZ#S"``$L\$`7<*J
MRF+!UN/0\Q``!+D:`*;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@B;/-`)6Y
M@@"!N1H`J.R!(K\^5>R!`B$>5KGG@':Y@@!SN0@`J;D:`-?L6CN_)57L<R*_
M/E7L6B`Z!5;L<P(A'E:Y!``WXS`@(``(P#H`````XS`@(``DXQ#S&``$PAK*
M8L'6N1H`%KGH4&VYYW#8[)8@OP!5N>>@/>Q6.[\E5;D:`!/L60`Z!5:Y"``5
M[-HBOSY5ZUD``@`,[-H"(1Y6[%D`(1Y6N>?0-[D(`%2YZ`!]P%H`````XU`@
M$``DN>=@`\!Z`````.-P(!@`).QA(+\`5>.@\R``!,*JRF+!UKD(`.JY&@#H
M[($[OR55N1H`X.R&`#H%5N,0\*``!+D(`.BY"``6P.H`````X^`@```DP!H`
M````XQ`@"``DU0?S*+`HIW0`"NMO\V``!`?^N00`#:?T]0?`Y?__\<0'!^MO
M\#``)./P_V#_<>PH`%P`?,08```_]^-P$````J>$`%.Y!`""N00`8^,`(```
ME+D$`)*5`"``IX0`3NP(``P]?D&0D`'C`)```)25`)``IW3_]AN8XZ!P```"
MIX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___!&["8`"0!^02F@`)4](`"G
MA``/0;"P"..@L````J=T_^FY!``JZV_PT``$!_Y!J:`!N>EP.[D$`"KK0P`#
M``I00&``ZV_PT``$!_ZGJ0``N00`*NMO\-``!`?^IY@``*?T_[\'!P<'ZZ_P
M4``DX_#^R/]QLD\`L+D$`*+KNP`@``U!,/"@LD\`L=('\3"P*,#E___Q;.PF
M`"$`?A@2ISA``%@@\+C`*P``\`#L(P`(@':E#Z``["``$V!VN00`*J<Y``+`
MY?__\=(0$J<:__^($``?I_0`!*<8``#5!_$PL"BY%``AIW0`!NNO\8@`!`?^
MP.7___$+ZV_P,``DX_#^P/]QLD\`D.N9`"``#;)/`)'2!_$XD"CL*``)`'RY
M!`!BE0`@`*=T``O5!_$XD"BG=`"6ZV_Q<``$!_[`Y?__\=:Y!`"R["C_\@!\
MN00`*\#E___P/.PH`&8`?$&@(!.5+B`3IW0`!I4`H`&GA/_PE2X@$Z>$`&.G
M"```N00`%KD$`"JG.0``LEX`,J<4__ZY"0`ZIXD``+)>`(&G%/_^N0D`AAJ#
MIXH``KD4`(BY!``HP.7__^[;XZ#PH``DISD``KD$`**Y!`!(P%```!$]P.7_
M__%<N00`*D$P\*C`Y?__[Y7L*``-_WY8`/#`ITA``,`+``#P`.P$`"N`=KD$
M`"K`Y?__\,.Y!``JP.7___#^N00`*\#E___OV>PF_Z``?+D$`"O`Y?__[I&Y
M!``FP.7__^[,I_3_>I4NH`&G=/^=E0"@`J>$_X.G]/^7N00`*L#E____4Z?T
M_]C`Y?__\%8'!P<'!P?K;_`P`"3`$```/J'C\/]8_W'CL!````3`4```,1S$
M2```/IG`,```$-^R3P"@ZZH`(``-LD\`H>,KH```!,!@```2.L#E___P_KD$
M`%;E2/"@``#`0```#-;C*Z````3`,```$,_`Y?__[UWK;_#8``0'_@<'!P?K
M?_`X`"3C\/``_W'C`/_X`"#C\/]8_W'C`/"@`"#C$/"@`7&Y!`"#09#PH+)/
M`+"Y!`"BZ[L`(``-N00`.;)/`+'2!Q``L"BG20__P"```!"HP.7__^[+["P`
M$@!^[`+__P#8&!*Y%``@03+PH)4`,`"G=``B[`8`'P!^P%```#XJX^!0```$
MN00`2+D$`#KC+K````3`Y?__[FGC0/"@`7'5!T``L"BG=``IZW_PX`$$!_X8
M$+D4`'&Y!``IN00`1Z<Y`"_`Y?__[J'L*/_8`'RY!`!)P(```#W]N00`5^.0
M@```!+D$`#KC*;````3`Y?__[SRG]/_3P.7__^^7ZV_P,``DX_#_0/]QLD\`
M8.MF`"``#;)/`&&Y!`"RT@?PN&`HN00`HY4],`"G=``$0:`P`:<(``"Y!``:
MIXD``+D$`"NR7@"!IQ3__D$P\+2Y"0"*P.7___VJ["@`EP!\IP@``*?9``"Y
M!``2LEX`T:<4__ZY"0#2[(T`=L!EXW#PM``4Q-@``#V2ZW<``P`-XR"P``"4
MN00`2Y4`L`"G=``-I_0`\$%`0`'C($```)25`$``IX0`!>PF__<]?KD)`$NY
M%`"402B0`KD$`(?C@-````C`Y?__[5KC((```"3L*``Y`'SC,-````3C`+``
M`)#C5S````1"`%``0>"P`1AP[`8`$`!\I_0`/.,0X```D$(0L`%!X.`!&''L
M&``R`'Q"</"@N00`M94]\*!!4%`!IW3_[9(]L`"GV0``XTV@``"00DVP`:?;
M``'L1O_Y`'S5!_"X8"BG=`"@ZV_P\``$!_ZGF0``XXF@``"00HD@`*>;``'L
MAO_Y`'RG]/_KN00`M:?T_]G$V```/1#C<-````3C$'````*GA`!XN00`1Z>8
M```8*:>:``%!0$`(XS!````"IW3_^*<J``.Y%``"ZS```P`-XS#PJ``DP%``
M`#UEXQ!0```2IW0`/,#@```]7>,@\*@`!.5,X````<#E___LS.,@\*``).PH
M_ZL`?+D$`#?C4/"H``2Y%`!YZW<``P`-N00`1\#E___O9^,@\*``!.,@T```
M)%"0\+3C4/"@``2GF@`!N10`F>LY``,`#4'C4`#E2.````"G]/\AXS#PJ``$
MN00`)\#E___MAN,@\*``).,@T```).PH_W(`?+D4``GK<``#``VG]/_7IYD`
M`*?T_R#E2/"H`!"GF```I_3_G<#E___N2`<'LD\`(,`0```\ENLR`"``#>-`
M$```!+)/`#'`4```+P_C)#````3$2```/(G`,```#L_`]/__[OOK;_`P`"3C
M\/``_W'C`/_X`"#C\/``_W'C`/_X`"#C\/](_W'C`/"P`"#C$/"P`G&R3P"0
MZYD`(``-LD\`D>.P\*\!<=('$`"0*,#E___MP\`````.R.,`\*``)+D$`&*G
M21`!ISD``KD$`"O`4```#K1!@/"NP.7__^ZMN00`*[D$`#BG21``P.7__^S$
M["0`,0!^['(``0#8N00`8KD4`'>Y!``GP.7__^P%N00`HNPH`!(`?+D4`+:Y
M!`!7N00`.+D$`$O`Y?__['5!*Z``D@`@`.,P\+`"<=4',`"0**=T``RY!``J
MZV_PZ`($!_ZGJ0``I_3_\,#E___MK`<'P/3___^`!P?K;_`P`"3C\/``_W'C
M`/_X`"#C\/ZP_W'C`/%(`"#C$/%(`7&Y!`"RN00`D[)/`'!!,/"TZW<`(``-
MP"````Y2LD\`<=('$`!P*,#E___[OZ<Y`"^Y!`"BN00`*\#E___MANPH`!D`
M?,`@```.0+D$`#O`Y?___=>Y!``KXX#Q2`%QU0>``'`HIW0`[>MO\8`!!`?^
MN00`*<#E___LB,`P```.+,#E___KTKD$`&+L*/_=`'Q!D/%(08#PN)4`8`"G
MA`"D[*@`#P!\IP@``+D$`#:Y!``JLET`,J<4__ZGA`"$IP@``*=)``"Y!`!6
MLEX`1:<4__ZYZ6`DXQ!/__]Q[&$`-Z!EN>E@`:<!``&GA``.E2\0`*=T`""2
M`!``XQ`?__]Q[&$`&8!DZ^```0`,E2\0`*=T`!&2`!``ZR\?__]5IW0`"NL`
M'___4N,0'_[_<:?G_^^G"```IRD``+D$`#:R7@`CIQ3__KD)`":G"```ITD`
M`+D$`%NGZ0__LEX`1:<4__ZY"0!+000@`>P._VT@9<`0```-LN.P\*@`).,0
M\*``)*<Y``*Y!``IP%````X<ITD0`,#E___MB+D$`#BY!``IP.7__^O!["8`
M#0!^6&#PT*4_@`#`:P``\`#L8P`H@';`,```#8BG*0``P.7__^LLN00`8NPH
M_S<`?)4`8`"G=/]@[*@`!P!\E2Z@`*>$``FG*0`!P&````UAI_3_IY4`H`&G
MA/_?I_3_];D$`"FG.0`!P.7__^TX[";_U`!^N00`.<`@```-4,#E___\Z;D$
M`"G`Y?__ZZBG]/\/P.7__^QSZ[_P6``DISD`+^/P_V#_<;D$`++`Y?__[0;L
M*``%`'Q!L"`!N00`*^N_\/@`!,#T___KB0<'!P?KG_!(`"3C\/``_W'C`/_X
M`"#C\/]8_W'C`/"@`""R3P"@XQ#PH`%QZZH`(``-LD\`H=('$`"@*.PH`&0`
M?)4`(`"GA`!?IP@``*>9``"Y!``RLEX`DZ<4__ZG"1``N0D`DNQ)``$`V>Q`
M`&\@9;D$`#)!L/"@N00`*\#E___M-^-9O___<>Q;`!_`9;GIL"6G40`!IW0`
M1^M"``$`#)4O4`"G=``1D@!0`.LO7___5:=T``KK`%___U+C4%_^_W&G1__O
MN00`*Z<Y`"_`Y?__[([L*``7`'SL*P`S(&6Y!``KP.7__^L3X^#PH`%QU0?@
M`*`HIW0`+>N?\/`!!`?^XQ#PH`%QU0<0`*`HIW0`(<`@```,ENN?\/`!!,#T
M___J]I4O4`"G=/_/D@!0`.-07___<>Q;_[)@9*?T_\62`"``I_3_SJ<I``"G
M]/_/P.7__^NM!P<'!^NO\%``)./P_U#_<;)/`*#KJ@`@``VR3P"A0;#PI-('
M\*B@*+D$`#O`(```#&W`Y?__^='L*``N`'SC0/"D`!3$*```.<CK%``#``WC
M$"````CC4!`(``3C4!```"3L6/_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\
MN00`.\`@```,0L#E___YINPF_]@`?+D$`#O`(```##S`Y?__^9OL*``N`'SC
M$/"D`!3$6```.9+KX0`#``WCX%````CC`.`(``3C`.```"3L"/_C`'SC,.`0
M``3C,.`(`"1!X.`([#;_^`!\N00`.\`@```,$<#E___Y<.PF_]@`?+D$`#O`
M(```#`K`Y?__^67L*``N`'SC4/"D`!3$Z```.5SK10`#``WC0.````CC,$`(
M``3C,$```"3L./_C`'SC($`0``3C($`(`"1!0$`([";_^`!\N00`.\`@```+
MW\#E___Y.NPF_]@`?+D$`#O`(```"]G`Y?__^2_L*``N`'SC,/"D`!3$*```
M.2;K$P`#``WC$"````CC0!`(``3C0!```"3L2/_C`'SC`!`0``3C`!`(`"1!
M$!`([`;_^`!\N00`.\`@```+KL#E___Y!.PF_]@`?+D$`#O`(```"Z?`Y?__
M^/GL*``N`'SC$/"D`!3$2```./#K40`#``WC4$````CC`%`(``3C`%```"3L
M"/_C`'SCX%`0``3CX%`(`"1!4%`([.;_^`!\N00`.\`@```+?,#E___XSNPF
M_]@`?+D$`#O`(```"WG`Y?__^,/L*``N`'SC0/"D`!3$6```.+KK-``#``WC
M,%````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``3C(#`(`"1!,#`([";_^`!\
MN00`.\`@```+3L#E___XF.PF_]@`?+D$`#O`(```"QO`Y?__^(WL*``N`'SC
MX/"D`!3$*```.(3K'@`#``WC$"````CC,!`(``3C,!```"3L./_C`'SC`!`0
M``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```*\,#E___X8NPF_]@`?+D$`#O`
M(```"Q/`Y?__^%?L*``N`'SC$/"D`!3$.```.$[K00`#``WC0#````CC`$`(
M``3C`$```"3L"/_C`'SC4$`0``3C4$`(`"1!0$`([%;_^`!\N00`.\`@```*
MZ,#E___X+.PF_]@`?+D$`#O`(```"N+`Y?__^"'L*``N`'SC,/"D`!3$2```
M.!CKXP`#``WCX$````CC4.`(``3C4.```"3L6/_C`'SC(.`0``3C(.`(`"1!
MX.`([";_^`!\N00`.\`@```*M\#E___W]NPF_]@`?+D$`#O`(```"K'`Y?__
M]^OL*``N`'SC4/"D`!3$Z```-^+K%0`#``WC$.````CC(!`(``3C(!```"3L
M*/_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```*AL#E___WP.PF
M_]@`?+D$`#O`(```"DC`Y?__][7L*``N`'SC$/"D`!3$*```-ZSK,0`#``WC
M,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``3C0#`(`"1!,#`([$;_^`!\
MN00`.\`@```*'<#E___WBNPF_]@`?+D$`#O`(```"DK`Y?__]W^Y!``R["@`
M"0!\P"````HUP.7___F@N00`.\`@```*0,#E___W;+D$`#+L*``)`'S`(```
M"C[`Y?__^8VY!``[P"````H\P.7___=9N00`,NPH`!H`?,`@```)W,#E___Y
M>M4'\*B@**=T`"/`,```"C?`(```">[KK_$```3`]/__^6FY!``[P"````H@
MP.7___<UN00`,NPH_^4`?,`@```)YL#E___Y5J?T_]S`Y?__Z.4'!P<'Z[_P
M6``DP"````G6X_#_4/]QLD\`L$$P\*3KNP`@``VR3P"QT@?PJ+`HP.7___<+
M["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`$.PQ/[\!5=4'\*BP*+D4`".G
M=``*Z[_Q"``$!_ZG.```I_3_\\#E___HJ`<'8`#P@&`@\(A@0/"08&#PF.L_
M\!@`),08```W`>/P_SC_<;D$`$)!`/%HLD\`($%0\,CK,@`@``VR3P`QXR`0
M```$T@?PP#`HXU#PN``DXP#PL``DY4CPH``!Y4CPJ```05#PH*<Y``+`Y?__
MZ$"G*0#_P.7__^?[ZX_P0``DX^#P`/!QX_#P`/]QXP#_^``@N2$`_J<D__BY
M!`#^X_#_4/]QXP#PJ``@XQ#PJ!!QN00`@K)/`*"G20`"ZZH`(``-ISD``+)/
M`*'2!Q``H"C`Y?__YHWLDO__`-GL"3"``%7LE`"Z`'RY"0"00;#PH.R4`)\`
M?+D$`#FY!``HITD``,#E___F=.PH`+C_?+D$`#NY!``HP$$``0`(P.7__^AW
M["@`I?]^N10`,NP\`'@'?>,3O_C_<>P;`')`9>Q!/K\`5<!0```V>]4'4``0
M`*>$`'WC$!___W'L&P!A0&7L2``M`'SL2``<`7SL2``.`GS`X```-F35!^``
M$`"GA`!FXQ`?__]QP"```#99U0<@`!``IX0`6^,0'___<<`P```V3M4',``0
M`*>$`%#C$!___W'L&P`T0&7`0```-D#5!T``$`"GA`!"XU`?__]QP.```#8U
MN00`%=4'X`!0`*>$`#7C$%___W'`(```-BC5!R``$`"GA``JQ`@``#8@XQ!?
M_O]QXP!?_O\@IX0`'^,07_W_<>P;_]*@9<*4``$``,`Q__\``.R3_V=@9*<I
M___C@/"H$''5!X``H"BG=``CZX_P\!`$!_ZYZ;`AN0@`*:?T__"G"___P"'_
M_P``N8$``J<+``&G]/]`P"````BHP.7___[(P"````B;P.7___["P.7__^=C
MZ^_P<``DX_#_8/]QP.7__^5*P.7__^4G["@`!@!\XR`@```$Z^_Q$``$!_X'
M!P<'ZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@```(=M('
M\+B@*,#E___U<>PH``D`?+D$`+*5`"``IW0`$M4'\+B@**=T`$^Y!``VP"``
M``A=ZV_P\``$P/3___>$IP@``+D$`#NY!``6IRD``*=)``"R7@`AIQ3__K)>
M`$.G%/_^N0D`)KD)`$M!DD`"N00`*<#E___E*^.P\*@`),`````'S.,`\*``
M)+D$`$FY!`"RP%````@ZISD``L#E___GIM4'\+B@**=T``VY!``[P"````@;
MZV_P\``$P/3___="P.7__^;3ZV_P,``DLD\`$./P_BC_<>LQ`"``#;)/`#'C
M,/#(`"32!_'0,"C`0```-35!@/#4N00`.-)'\/A`$-(/\.!`6-('\/!`:.,@
M\,``),`@```'=<#E___TY^PH``D`?+D$`+*5`"``IW0"EL#E___DB\#E___D
M:.PH`3D`?..@(````J>$`3.G"```IRD``+D$`%JR7@`EIQ3__KD)`"KKL@`!
M``VGNP`!N00`*\#E___DJN,`H```E+D$`)*5`*``IX0"?+D$`'NY!`#2N00`
M2[D$`"FYA`!@P%````>OISD``D&@H`'`Y?__YQVY(0![N00`2[GBH$?C`*``
M`)2YZ;!4IUL``KDA`%2YXE!4N>E`*T&0D`+CLE_^_W&5`*``IW3_UD%@\1C`
M(```!U:G]``)IVL`".,@;_C_`J>$`""Y!``XP.7___1NN00`<NPH__(`?)4`
M(`"GA/_MP.7___32["C_Z`!^N00`)\#E___E2KD$`&+L)@`=`'Q!D/#XXV"0
M```"IX0`%94`8`"GA`"IN00`)L#E___TM>PF`)0`?J>;``CC8)````*G=/_O
MIP@``+D$`.VG&0``LEX`'J<4__ZY"0`=I[D``+D$`*:R7@"ZIQ3__KD)`+8:
ML:>Z!`2Y%`";N00`*<#E___D"\`````&L./0\+``).,`\*``)+D$`'*G.0`"
MN00`2<#0```''./0\*@`),!0```'$<#E___F@+D$`">G.0'`P.7__^5I["8`
M"_]^P.7__^4S6#`@`.PV`8H1?D'0\4"Y!``GN00`/<#E___EU1BB["8`#0!^
M6$#Q6*=80`#`2P``\`#L10"$@':Y!`!GQ(@``#/ZXW#PP``$P$````<`XU!P
M```$XR"````$ISD``L#E___EH:>Y``#C8/#(``35!_'08"BG=`(<N00`*^MO
M\@@`!`?^N00`)J>;``C`Y?__Y)JY!`!B["C_50!\I_3_:J=I``"G]/]F06#P
MX.,@8````J>$`!6Y!``XP.7___.3["@`!P!\E0`@`*=T`!VG:P`(XR!@```"
MIW3_[Z<I``VG>0`-I[D`#<#E___C;,"@```&@+D$`)*Y!`#2IP@`4Z?T_L;`
MY?__Y%ZY!`"B["C_X`!\IP@``*?I``"Y!``RLEX`XZ<4__ZY"0#BZ[X``0`-
MI[L``:?T_IE88/%<P.7__^,![&+_>F!V6+#Q6*<H`<#`NP```?_LLO]P8':Y
M!``IP.7__^,ON00`.+D$`++`(```!I;`Y?__\S6Y!``R["@!``!\XQ#PP``$
MXR`0```$P.7___=#N00`8NPH`/(`?*<(``"G20``N00`-K)>`$.G%/_^N0D`
M1NQ,`!X#?KD4`%3`$```!F_C)6_\_W&R70`2IQ3__J=T``_L2`%#!'ZG2O_[
MN10`Y$%.8`"5+T``IX0!.+D$`#C`(```!:S`Y?__\O#L*`#%`'SC`"```)3L
M"`"_`'[L"`"\,'[`,```!=+`(```!9>Y!`!GP.7___4%P.7__^16P%````:<
MP!````5HN00`TN-0\+``)+D$`$FY!``KXQ#PH``DX]#PJ``DP%````8SISD`
M`L#E___E.:?T`#3`Y?__X_18("``IRX`$:=T`#7`Y?__Y"O`,```!4"Y!``"
MIZH``<"````&:N,P\*``)+D4`-JY!`!GN00`2;D$`"OC@/"X`"3C`/"H`"3`
M4```!@GCT/"P`"2G.0`"P.7__^4%N00`*Z<Y`<#`Y?__X^[L*/_'_WZY!``G
MP.7__^2VN00`.\`@```$_,#E___TFKD$`"O`Y?___.&G]/ZJN10`0^,0\,``
M!+D$`&?C4!````3$*```,H+C0/"@`"2G.0`"P$````5HXR`@```$P.7__^0L
MI_3^B\#E___\O^-P\,@`!-4'\=!P**=T`*2Y!``KZV_R"``$P/3__^,GN00`
MTJ?T_;3CX/#```3C8.````2G]/\+N00`)J<Y``#`Y?__Y'2Y!`!B["C_/@!^
MP.7___MTN00`@NPD_S8`?*=)``#C,(_V_W&Y!``FP.7__^(=N00`)D$P\-JG
M20`&P.7__^0D["8`:@9\P#```"2;U04P`/#:IW3_%^,PC\[_<:=)``"Y!``F
MP.7__^'_N00`)KD$`#VG20`HP.7__^0&["8`3"A\P.````6IP%````1UN00`
M2>-0\*``)+D$`&>Y!``KD@#Q:./@\+``)./0\*@`),!0```%-J<Y``+`Y?__
MY$2G]/])XS#PP``$XU`P"``"IX3^Q*<(``"G&0``N00`);)>`!*G%/_^N0D`
M%>P<_K8#?>/A7_S_<<!````%";)=`$ZG%/_^N>*`9:?T_J?`Y?__XUK`(```
M!/[`Y?__^K`'!^M_\#@`)./P_U#_<<"@```QGK)/`+#C$*````3KNP`@``VR
M3P"QXY&P```$08#PI-('\*BP*-(`D+&0L+D$`#C`(```!!O`Y?__\6WL*``'
M`'R5,2``IX0`TL#E___W>^,@H```!..2L```!+D$`"FG60`#ITD``<`P```$
MV<#E___AH;D$`)+L*``?`'SC,"`0``3C<*````3C,#````3`0```!,;C)[``
M``3`Y?__X9KC0)`0``3C,$````210#`-IW0`L^-PH```!*=9``/C)[````2G
M20`!P#````2LP.7__^%PN00`DNPH`!P`?+D$`#C`(````Z;`Y?__\1.Y!`!"
M["@`@0!\XQ"0$``$XR>P```$XS`0```$P.7__^%BXZ"@```$ITD``>-ZL```
M!,`P```$@;D$`"?`Y?__X++`0```!(2Y!``RN00`)\#E___A2+D$`#C`(```
M`V[CBK````22`("QP.7___#;Q"L``#%8N00`DNPH`"P`?+D$`"FG.0'`P.7_
M_^(\[`(``0#8[`P`%@%_["@`$Q%^N00`4L2X```Q.KD$`$G`(```!&+C,+``
M``3`Y?__XL/5!_"HL"BG=``YZW_PZ``$!_[$*```,2/`Y?__^Y3$*P``,2&Y
M!`"2[";_S`!\P"````0QP.7__^*FE0`@`:>$_S>G]/\LXU"0$``$Q.@``#$&
MXR!0```$XS#@```$P.7___(MI_3_?^,GL```!,#E___B*:?T_TG`Y?__XC0'
M!^N?\$@`)./P_U#_<;)/`*"Y!`"RZZH`(``-03#PI+)/`*'`(````QC2!_"H
MH"C`Y?__\%GL*``3`'SC$"```)3L&``-`'[L&``*,'[LN``'`'R5`+``IW0`
M"]4'\*B@**=T`#3KG_#X``0'_KD$`"O`Y?__]:2G.0`ON00`DL#E___BD>PH
M``4`?$&0(`&Y!``IP.7__^$7ITD`!,`P```#-<#E___@G^PF_]D`?M4'\*B@
M**=T``JY!``KZY_P^``$P/3___#'P.7__^',!P?K[_!P`"2G*0"`X_#_8/]Q
MP.7__]_PP#%G12,!P`_OS:N)XS`@```DXP`@"``DP$^8NMS^P%$0,E1VXT`@
M$``DXU`@&``DP#_#TN'PY4@@*```XS`@(``DY4@@,```Y4P@>```Z^_Q$``$
M!_X'!P<'ZV_P,``DZQ0``P`-N00`LN,@("@`!+D(`!+L42"_`%6Y!`"4X_#_
M8/]QXT"P,``$N00`H[DQ`"&GQ``$ITL``>-0L"@`).L)`!T`#+D(``3C`+`P
M`"3CT+!X`!*G=`"%07"P..R<`*H_?NQI_\``V(A@``;LY@`!`-CL'A^Y!E7L
M4?_``-E!T:``ZX4`!@`,IXL``>Q(/K\`5:>$`"GL2``:`7SL2``-`GS2/W``
MH`"Y!``K0:"@0,#E___D*-(_<`"@`+D$`"M!H*!`P.7__^0>TC]P`*``N00`
M*T&@H$#`Y?__Y!3LK0`J@&3KB``"``S2/W``H`"Y!``KP.7__^0&TC]P`*!`
MN00`*\#E___C_M(_<`"@@+D$`"O`Y?__X_;2/W``H,"Y!``K0:"A`,#E___C
M[*>'_]ZGFO_`B6``!AN6N10`F;D$`#VY!``GN00`2<#E___B!E"0L'CK;_#0
M``0'_J>(`$`;C1F)07"P.+GR,(FY!``GN1@`+;D$`#JY%`!HN00`1L#E___A
MZQ@X6C"P>%`PL'CL-O_B0'X;F+D$`"NY"`"FN10`F<#E___CK:?T_UBY!`#:
MI_3_QNM_\#@`)+D$`+/C@#`H``3CD#`P``3L&#J_/57C\/]@_W&Y%``Q04.P
M.)*`0`"G&@`!N00`HKD4``%!(+`XN0@`(.P<`)XX?J?H`$"Y^1`^[.$`7X!V
M[!/__P#8N00`,NM!``@`WNQ(`$\`?NQT__\`V!A4[`0^OP!5IX0`)NP(`!D!
M?NP(``P"?N,@)```-AA'03`A`-?_(``@`.,@-```-J=*___7_S``,`!!,#$`
MXR`T```VU_\P`#``03`Q`.Q(`"(!?NLE``(`WN,@-```-M?_,``P`.,@-0``
M-M?_,0`Q`.,@-@``-M?_,@`R`.,@-P``-M?_,P`S`$$P-`"G)O_FN18`X<;@
M````H+D$`"O`Y?__XQO7-[`XL#BG.0``[#D`!V!5[#D(#V!5[#D0%V!5[#D8
M'R!5N00`*^R#`!\`5>.`L'``),#E___B_](#H`"P!+D$`"O2`Z`$L`S2`Z`(
ML!32`Z`,L!S2`Z`0L"3K?_#8``3`]/__X'2G6``XN?D0=>Q1_\R`=NP7__\`
MV+D$`#+K<0`(`-[L>`!/`'[LY___`-@85^P'/K\`5:>$`";L"``9`7[L"``,
M`G[C("0``#88?D$P(0#7_R``(`#C(#0``#:G>O__U_\P`#``03`Q`.,@-```
M-M?_,``P`$$P,0#L>``B`7[K10`"`-[C(#0``#;7_S``,`#C(#4``#;7_S$`
M,0#C(#8``#;7_S(`,@#C(#<``#;7_S,`,P!!,#0`IT;_YKD6`"'&(`````BG
M]/]MUP`P`#``UP`P`#``!P<'!\18```M^,#T___=P0<'!P?K;_`P`"3C$/!X
M``2G^_]@XQ#P```DP,```"S-XT#Q$``$ZV_PT``$!_0``````````@`!)7,O
M)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4```O<')O8R]S96QF+V5X90``+W!R;V,O)6DO)7,`97AE`"X`4$%2
M7U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%
M4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M``!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@``,0!L<V5E:R!F86EL960``')E860@9F%I
M;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@``"5S)7,E<R5S``!P
M87(M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!0051(``!P87)L```N<&%R``!S:&]R="!R96%D```E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#8S`%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`55-%4@``55-%
M4DY!344``%1%35!$25(`5$U0`"]T;7``````<&5R;'AS:2YC``!#04-(10``
M`````````1L#.P```.P````<__^`F```!C3__X,8```!"/__A"````$X__^:
MN````7C__YN8```!V/__G"@```((__^=F````D3__YX0```"@/__GQ````+`
M__^AL````P#__Z'H```#%/__HN@```-8__^B\````VS__Z58```#K/__I9``
M``/8__^FZ```!"#__ZQX```$5/__K/````2$__^M:```!+#__Z]X```$]/__
MKZ@```44__^PF```!63__[>8```%M/__N=@```7P__^ZJ```!G3__[L8```&
MF/__O-@```;8__^_,```!Q@`````````%``````!>E(``7@.`1L,#Z`!!PX`
M````%````!S__X((````0@``````````````%``````!>E(``7@.`1L,#Z`!
M````````/````!S__X+@```6E@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'
M`Q9Z"L_.S<S+RLG(Q\8.H`%""P```````%P```!<__^9.````-P`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@[``@*8"L_.S<S+RLG(Q\8.H`%""UP*S\[-S,O*
MR<C'Q@Z@`4(+3@K/SLW,R\K)R,?&#J`!0@L``````"P```"\__^9N````)``
M1HH*BPF,"(T'C@:/!48.V`,"?`K/SLW,R\H.H`%""P```#@```#L__^:&```
M`6H`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`W8*S\[-S,O*R<C'Q@Z@`4(+
M`````#@```$H__^;3````'0`3(8.APV(#(D+B@J+"8P(C0>.!H\%1@[(`@)@
MS\[-S,O*R<C'Q@Z@`0```````#P```%D__^;B````0``1H<-B`R)"XH*BPF,
M"(T'C@:/!48.H"%,#L@B`IH*S\[-S,O*R<C'#J`!0@L````````\```!I/__
MG$@```*>`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`(#`58*S\[-S,O*R<C'
MQ@Z@`4(+````````$````>3__YZH````.`````````!````!^/__GLP```#^
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.H"%,#J!!3`[80@+*"L_.S<S+RLG(
MQ\8.H`%""P```!````(\__^?B`````8`````````/````E#__Y]\```":`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#J`A3`[P(P)Z"L_.S<S+RLG(Q\8.H`%"
M"P```"@```*0__^AI````#0`2HL)C`B-!XX&CP5&#L`"7L_.S<S+#J`!````
M````1````KS__Z&P```!5`!&B0N*"HL)C`B-!XX&CP5&#J`A3`[((@+F"L_.
MS<S+RLD.H`%""UP*S\[-S,O*R0Z@`48+````````,````P3__Z+````%C`!&
MB@J+"8P(C0>.!H\%1@[0`@,%2@K/SLW,R\H.H`%&"P```````"P```,X__^H
M'````'8`3(L)C`B-!XX&CP5&#M`"`E0*S\[-S,L.H`%""P```````"@```-H
M__^H9````'@`7(8.APV(#(D+B@J+"8P(C0>.!H\%1@[H`@``````0````Y3_
M_ZBP```"$`!&B`R)"XH*BPF,"(T'C@:/!48,#J"!!%@-#T8.T(($`P&D"L_.
MS<S+RLG(#J`!0@L````````<```#V/__JGP````L`$:.!H\%1@[``E[/S@Z@
M`0```$P```/X__^JC````/``1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`@)4
M"L_.S<S+RLG(Q\8.H`%&"P)^"L_.S<S+RLG(Q\8.H`%&"P``````3```!$C_
M_ZLL```&_@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#O@$`P*R"L_.S<S+RLG(
MQ\8.H`%""P,"[@K/SLW,R\K)R,?&#J`!1@L````X```$F/__L=P```(^`$:'
M#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P'$"L_.S<S+RLG(QPZ@`4(+``````!`
M```$U/__L^````#.`$:)"XH*BPF,"(T'C@:/!48.T`("7@K/SLW,R\K)#J`!
M0@L"5@K/SLW,R\K)#J`!1@L``````#P```48__]Z7````H``1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[H`@,!P`K/SLW,R\K)R,?&#J`!0@L````````@```%
M6/__M"P```!L`$J.!H\%1@[``@):S\X.H`$````````\```%?/__M'@```'`
M`$R&#H<-B`R)"XH*BPF,"(T'C@:/!5X.P`(#`3H*S\[-S,O*R<C'Q@Z@`4(+
M````````/```!;S__[7X```"5`!&APV(#(D+B@J+"8P(C0>.!H\%7`[``@,!
M5@K/SLW,R\K)R,<.H`%&"P```````````!````7\__^X$`````P`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"D`````````*+@`````
M`````0````````+:``````````$````````"Y0`````````=````````!&$`
M````````#````````!Y@``````````T```````!D*``````````9````````
MNZ@`````````&P`````````(`````````!H```````"[L``````````<````
M``````@`````````!`````````*0`````&___O4````````'H``````````%
M````````$3@`````````!@````````B```````````H````````$E0``````
M```+`````````!@`````````%0````````````````````,```````"]V```
M```````"````````!1``````````%``````````'`````````!<````````9
M4``````````'````````%O@`````````"`````````)8``````````D`````
M````&``````````>``````````@`````;___^P`````(```!`````&____X`
M```````6B`````!O____``````````$`````;___\````````!7.`````&__
M__D`````````#@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````N[@`````````````````````````````'LX````````>[@``````
M`!\.````````'RX````````?3@```````!]N````````'XX````````?K@``
M`````!_.````````'^X````````@#@```````"`N````````($X````````@
M;@```````"".````````(*X````````@S@```````"#N````````(0X`````
M```A+@```````"%.````````(6X````````AC@```````"&N````````(<X`
M```````A[@```````"(.````````(BX````````B3@```````")N````````
M(HX````````BK@```````"+.````````(NX````````C#@```````",N````
M````(TX````````C;@```````"..````````(ZX````````CS@```````"/N
M````````)`X````````D+@```````"1.````````)&X````````DC@``````
M`"2N````````),X````````D[@```````"4.````````)2X````````E3@``
M`````"5N````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"6```````````````````#`"`I005(N<&T*````````````
M``````"DR````````&2T``````````````````!E5````````&58````````
MI+P```````!DN@```````*3$``````````````````"DK````````*2R````
M``````````````!G/$=#0SH@*%-54T4@3&EN=7@I(#$S+C(N,2`R,#(T,#4P
M.2!;<F5V:7-I;VX@8C=A,C8Y-S<S,V0Q.6$P.3-C8F1D,&4R,#!F9F-E,#8Y
M831B8S@Q,ET``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M``````````(````````".`````````(X``````````\`````````````````
M```!```````````````3````!P`````````"`````````D@````````"2```
M```````D````````````````````!```````````````)@````<`````````
M`@````````)L`````````FP`````````(`````````````````````0`````
M`````````#@````%``````````(````````"D`````````*0````````!1``
M```&```````````````(``````````@````T;___]@`````````"````````
M!Z`````````'H`````````#<````!@``````````````"```````````````
M/@````L``````````@````````B`````````"(`````````(N`````<````"
M``````````@`````````&````$8````#``````````(````````1.```````
M`!$X````````!)4````````````````````!``````````````!.;____P``
M```````"````````%<X````````5S@````````"Z````!@``````````````
M`@`````````"````6V____X``````````@```````!:(````````%H@`````
M````<`````<````!``````````@``````````````&H````$``````````(`
M```````6^````````!;X`````````E@````&```````````````(````````
M`!@```!T````!`````````!"````````&5`````````94`````````40````
M!@```!8`````````"``````````8````?@````$`````````!@```````!Y@
M````````'F``````````/@````````````````````0``````````````'D`
M```!``````````8````````>H````````!Z@````````!N``````````````
M```````$`````````"````"$`````0`````````&````````)8`````````E
M@````````#ZH````````````````````"```````````````B@````$`````
M````!@```````&0H````````9"@`````````*@````````````````````0`
M`````````````)`````!``````````(```````!D6````````&18````````
M0)`````````````````````(``````````````"8`````0`````````"````
M````I.@```````"DZ`````````#L````````````````````!```````````
M````I@````$``````````@```````*78````````I=@````````&0```````
M``````````````@``````````````+`````.``````````,```````"[J```
M`````+NH``````````@````````````````````(``````````@```"\````
M#P`````````#````````N[````````"[L``````````(````````````````
M````"``````````(````R`````8``````````P```````+NX````````N[@`
M```````"(`````<```````````````@`````````$````-$````!````````
M``,```````"]V````````+W8`````````B@````````````````````(````
M``````@```#6`````0`````````#````````P`````````#```````````"(
M````````````````````"```````````````W`````@``````````P``````
M`,"(````````P(@`````````*`````````````````````@`````````````
M`.$````!`````````#```````````````````,"(`````````%8`````````
M```````````!``````````$````!`````P``````````````````````````
D``#`W@````````#J`````````````````````0``````````
